package com.ruoyi.postCheck.mapper;

import java.util.List;
import java.util.Map;

import com.ruoyi.postCheck.domain.PostAssessmentRatingOther;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;

/**
 * 打分表(职能互评生产日常)Mapper接口
 *
 * @author csg
 * @date 2024-01-01
 */
public interface PostAssessmentRatingOtherMapper extends BaseMapper<PostAssessmentRatingOther>
{
    /**
     * 查询打分表(职能互评生产日常)
     *
     * @param id 打分表(职能互评生产日常)主键
     * @return 打分表(职能互评生产日常)
     */
    public PostAssessmentRatingOther selectPostAssessmentRatingOtherById(Long id);

    /**
     * 查询打分表(职能互评生产日常)列表
     *
     * @param postAssessmentRatingOther 打分表(职能互评生产日常)
     * @return 打分表(职能互评生产日常)集合
     */
    public List<PostAssessmentRatingOther> selectPostAssessmentRatingOtherList(PostAssessmentRatingOther postAssessmentRatingOther);



    public List<PostAssessmentRatingOther> selectPostAssessmentRatingOtherListGroup(PostAssessmentRatingOther postAssessmentRatingOther);

    /**
     * 新增打分表(职能互评生产日常)
     *
     * @param postAssessmentRatingOther 打分表(职能互评生产日常)
     * @return 结果
     */
    public int insertPostAssessmentRatingOther(PostAssessmentRatingOther postAssessmentRatingOther);

    /**
     * 修改打分表(职能互评生产日常)
     *
     * @param postAssessmentRatingOther 打分表(职能互评生产日常)
     * @return 结果
     */
    public int updatePostAssessmentRatingOther(PostAssessmentRatingOther postAssessmentRatingOther);

    /**
     * 删除打分表(职能互评生产日常)
     *
     * @param id 打分表(职能互评生产日常)主键
     * @return 结果
     */
    public int deletePostAssessmentRatingOtherById(Long id);

    /**
     * 批量删除打分表(职能互评生产日常)
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deletePostAssessmentRatingOtherByIds(Long[] ids);


    List<Long> getDeptIdList(Long id);

    List<Map<String,Object>> getDeptIdListByType(Integer type);

}
